bayespy.inference.vmp.nodes.dirichlet.DirichletDistribution.random
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletDistribution.random